\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{actasmonteiro}[2013/06/06 v1.00]

%% Opción para distinguir entre versión impresa y versión electrónica.
\newif\if@print \@printfalse
\DeclareOption{print}{\@printtrue}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{amsart}}
\ProcessOptions\relax
\LoadClass[]{amsart}[1996/10/24]


\def\publname{ACTAS DEL XIII CONGRESO\newline
  DR.~ANTONIO A.~R.~MONTEIRO (2015)}


%% Datos para el footer
\def\shortpublname{Actas del XIII Congreso Dr. Antonio A. R. Monteiro (2015)}
%\def\footervolumeissue{, Vol.~\currentvolume, No.~\currentissue,}

%\def\ISSN{0327-9170}

\def\emailaddrname{{\itshape E-mail}}


%% ----------------------------------------------------------------------------
%% Fonts
%% ----------------------------------------------------------------------------
% Usa la fuente Times Roman en math & text
\RequirePackage{mathptmx}
%\usepackage{txfonts}  % Ver LaTeX Companion 2nd ed.
\RequirePackage[T1]{fontenc}


%% ----------------------------------------------------------------------------
%% Copyright
%% ----------------------------------------------------------------------------
\copyrightinfo{}{}



%% ----------------------------------------------------------------------------
%% Logo
%% ----------------------------------------------------------------------------

% \def\@setdateposted{%
%   \newline Published online: \@dateposted}


\def\@logofont{\fontsize{7}{8\p@}\selectfont}            %% un punto más grande que en amsart
\def\article@logo{%
  \set@logo{%
    \publname
    \def\volinfo{2016}
    \def\pageinfo{%
      \ifnum\start@page=\z@
        P\'aginas 000--000
      \else
        \ifx\start@page\end@page
          P\'agina \start@page
        \else
          P\'aginas \start@page--\end@page
        \fi
      \fi}%
        \ifx\@empty\currentvolume
        \else \newline\volinfo, \pageinfo
        \fi
    %\newline \@PII                                      %% PII = Publisher Item Identifier (ISSN, etc.)
    \ifx\@empty\@dateposted \else \@setdateposted\fi
  }%
}

%% ----------------------------------------------------------------------------
%% Dimensions
%% ----------------------------------------------------------------------------
\RequirePackage{geometry}
\geometry{%
    paperwidth=210mm,  % ancho final del papel
    paperheight=297mm, % altura final del papel
    twoside=true,      % two sides, obvio
    tmargin=47mm,      % margen superior (20 deseado + 27 sobrante)
    bmargin=27mm,      % margen inferior
    lmargin=45mm,      % margen interno   (35 deseado + 10 sobrante)  (OK 2008)
    rmargin=25mm,      % margen externo   (valor deseado: 25)  (OK 2008)
    headsep=8mm,       % separación entre el running header y el área de texto 
    footskip=10mm,     % separación entre el pie y el área de texto
    %verbose,           % muestra los valores utilizados
    voffset=-14mm
}


%% ----------------------------------------------------------------------------
%% Header & footer
%% ----------------------------------------------------------------------------
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\renewcommand{\headrulewidth}{.2pt}  % línea delgada bajo el running head
\fancyhf{}  % --- limpia todos los campos

\fancyhead[RE,LO]{}
\fancyhead[CE]{\footnotesize \MakeUppercase{\shortauthors}}
\fancyhead[CO]{\footnotesize \shorttitle}
\fancyhead[RO,LE]{\footnotesize \thepage}

%\fancyfoot[LE,RO]{\scriptsize \textit{\shortpublname\footervolumeissue\ (\currentyear)}}
%\fancyfoot[LE,RO]{\scriptsize {\it Actas del XIII Congreso Dr.\ Antonio A. R. Monteiro (2015), 2016}}
\fancyfoot[C]{}
\fancyfoot[LO,RE]{}


%% Diferencias entre versión online y versión impresa.
%% Copiado de revuma.
\if@print
    % Genera una página en blanco extra al final si el artículo tiene un número impar de páginas.
    % Ver http://tex.stackexchange.com/questions/38218/how-to-keep-the-last-page-number-even
    %     http://tex.stackexchange.com/questions/69111/forcing-even-number-of-pages-in-output-latex-pdflatex
    \AtEndDocument{\cleardoublepage}

    % Para presentar correctamente las URLs que pueda haber en el texto
    % (p.ej. en las referencias). Para la versión electrónica, de esto se ocupa
    % el paquete hyperref.
    \RequirePackage{url}
    % De los enlaces solo queremos mostrar el texto, no la url.
    \newcommand{\href}[2]{#2}
\else
    %% ----------------------------------------------------------------------------
    %% Enlaces de hipertexto.
    %% ----------------------------------------------------------------------------
    %% TODO revisar estilo; comparar con AMS journals. P.ej., recuadrar en vez de
    %%      cambiar el color del texto.
    \RequirePackage[bookmarks,bookmarksopen,bookmarksnumbered,
                    %colorlinks,linkcolor=blue,
                    breaklinks,
                    linktocpage,   %% XXX WHY?
                    %backref,pagebackref, % backreferences pueden añadir un renglón en la bibliografía,
                                          % causando un salto de página diferente al de la versión impresa.
    ]{hyperref}
\fi
